@@ -7,6 +7,7 @@
 
 from urllib.parse import urlparse
 import io
+import json
 import ujson
 import os
 import pathlib
@@ -190,7 +191,7 @@ def get_encoding(bstr, *, maxn=100):
     enc = chardet.detect(bstr[start_idx:start_idx + maxn])['encoding']
 
     # 2 转换为常见编码名
-    if enc in ('utf-8', 'ascii', 'ISO-8859-1'):
+    if enc in ('utf-8', 'ascii', 'ISO-8859-1', 'Windows-1252'):
         return 'utf8'
     elif enc in ('UTF-8-SIG',):
         return 'utf-8-sig'
@@ -715,7 +716,10 @@ class File(PathBase):
                 with open(name, 'rb') as f:
                     bstr = f.read()
                     if not encoding: encoding = get_encoding(bstr)
-                return ujson.loads(bstr.decode(encoding=encoding))
+                try:
+                    return ujson.loads(bstr.decode(encoding=encoding))
+                except ValueError:  # ujson会有些不太标准的情况处理不了
+                    return json.loads(bstr.decode(encoding=encoding))
             elif mode == '.yaml':
                 with open(name, 'r', encoding=encoding) as f:
                     return yaml.safe_load(f.read())
