@@ -95,7 +95,7 @@ class Dir(PathBase):
 
         https://stackoverflow.com/questions/1392413/calculating-a-directory-size-using-python
 
-        >> Path('D:/slns/pyxllib').size  # 这个算的就是真实大小，不是占用空间
+        >> Dir('D:/slns/pyxllib').size  # 这个算的就是真实大小，不是占用空间
         2939384
         """
         if self:
@@ -108,6 +108,11 @@ class Dir(PathBase):
             total_size = 0
         return total_size
 
+    @property
+    def psize(self) -> str:
+        """ 美化显示的文件大小 """
+        return humanfriendly.format_size(self.size, binary=True)
+
     def __truediv__(self, key) -> pathlib.Path:
         r""" 路径拼接功能
 
