@@ -19,7 +19,7 @@ ____main = """
 
 from ._0_installer import *
 from ._1_typelib import *
-from ._2_chrome import *
+from ._2_browser import *
 from ._3_showdir import *
 from ._4_bcompare import *
 
@@ -41,7 +41,7 @@ def render_echart(ob, name, show=False):
     if not ob.page_title or ob.page_title == 'Awesome-pyecharts':
         ob.page_title = name
     f = ob.render(str(File(f'{name}.html', Dir.TEMP)))
-    if show: chrome(f)
+    if show: browser(f)
     return f
 
 
